import * as react_jsx_runtime from 'react/jsx-runtime';
import { RouteParams, RouteInstance, RouteQuery, HistoryRouter } from 'atomic-router';
import { AnchorHTMLAttributes, ForwardedRef, ComponentType, ReactNode, FC } from 'react';

type LinkProps<Params extends RouteParams> = {
    to: RouteInstance<Params> | string;
    params?: Params;
    replace?: boolean;
    query?: RouteQuery;
    className?: string;
    activeClassName?: string;
    inactiveClassName?: string;
} & AnchorHTMLAttributes<HTMLAnchorElement>;
declare const LinkView: <Params extends RouteParams>(props: LinkProps<Params>, ref: ForwardedRef<HTMLAnchorElement>) => react_jsx_runtime.JSX.Element;
declare const Link: <Params extends RouteParams>(props: LinkProps<Params> & {
    ref?: ForwardedRef<HTMLAnchorElement>;
}) => ReturnType<typeof LinkView>;

interface RouteProps<Params extends RouteParams> {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: ComponentType;
}
declare function Route<Params extends RouteParams>({ route, view: Component }: RouteProps<Params>): react_jsx_runtime.JSX.Element | null;

interface RouterProviderProps {
    router: HistoryRouter;
    children: ReactNode;
}
declare function RouterProvider({ router, children }: RouterProviderProps): react_jsx_runtime.JSX.Element;
declare function useRouter(): HistoryRouter;

interface RouteViewConfig<Props, Params extends RouteParams> {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: ComponentType<Props>;
    otherwise?: ComponentType<Props>;
}
declare function createRouteView<Props, Params extends RouteParams, Config extends {
    [key in keyof RouteViewConfig<Props, Params>]?: RouteViewConfig<Props, Params>[key];
}>(config: Config): (props: Props & Omit<RouteViewConfig<Props, Params>, keyof Config>) => react_jsx_runtime.JSX.Element | null;

interface RouteRecord<Props, Params extends RouteParams> {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: ComponentType<Props>;
    layout?: FC<{
        children: ReactNode;
    }>;
}
interface RoutesViewConfig {
    routes: RouteRecord<any, any>[];
    otherwise?: ComponentType<any>;
}
declare function createRoutesView<Config extends RoutesViewConfig>(config: Config): (props: Omit<Config, keyof Config>) => react_jsx_runtime.JSX.Element | null;

declare function useLink<Params extends RouteParams>(route: RouteInstance<Params>, params: Params, query?: RouteQuery): string;

export { Link, type LinkProps, Route, type RouteProps, type RouteRecord, type RouteViewConfig, RouterProvider, type RouterProviderProps, type RoutesViewConfig, createRouteView, createRoutesView, useLink, useRouter };
